aboutsummaryrefslogtreecommitdiffstats
path: root/test/vpp_interface.py
diff options
context:
space:
mode:
authorMatej Klotton <mklotton@cisco.com>2016-11-11 11:38:55 +0100
committerDamjan Marion <dmarion.lists@gmail.com>2016-11-15 15:32:48 +0000
commit86d87c40dd97ced69c939299204fadf1859a2f50 (patch)
tree892a3adc4906186922354ef4f9381ff490dd9415 /test/vpp_interface.py
parentb7c3f2c61c25e3a9e729c5ea7e4a0117f717a2c5 (diff)
Update test documentation.
- update IRB, IPv4, ipv6 doc - revert 778c2765c8ea5c6628f6d668847f0b9ae06dbf3d Change-Id: I9af5ed9329ce5fe01392cf28d5bf321cfc647e48 Signed-off-by: Matej Klotton <mklotton@cisco.com>
Diffstat (limited to 'test/vpp_interface.py')
-rw-r--r--test/vpp_interface.py85
1 files changed, 54 insertions, 31 deletions
diff --git a/test/vpp_interface.py b/test/vpp_interface.py
index d74248a3..30ef8ae7 100644
--- a/test/vpp_interface.py
+++ b/test/vpp_interface.py
@@ -6,59 +6,57 @@ from util import Host
class VppInterface(object):
- """
- Generic VPP interface
- """
+ """Generic VPP interface."""
__metaclass__ = ABCMeta
@property
def sw_if_index(self):
- """Interface index assigned by VPP"""
+ """Interface index assigned by VPP."""
return self._sw_if_index
@property
def remote_mac(self):
- """MAC-address of the remote interface "connected" to this interface"""
+ """MAC-address of the remote interface "connected" to this interface."""
return self._remote_hosts[0].mac
@property
def local_mac(self):
- """MAC-address of the VPP interface"""
+ """MAC-address of the VPP interface."""
return self._local_mac
@property
def local_ip4(self):
- """Local IPv4 address on VPP interface (string)"""
+ """Local IPv4 address on VPP interface (string)."""
return self._local_ip4
@property
def local_ip4n(self):
- """Local IPv4 address - raw, suitable as API parameter"""
+ """Local IPv4 address - raw, suitable as API parameter."""
return socket.inet_pton(socket.AF_INET, self._local_ip4)
@property
def remote_ip4(self):
- """IPv4 address of remote peer "connected" to this interface"""
+ """IPv4 address of remote peer "connected" to this interface."""
return self._remote_hosts[0].ip4
@property
def remote_ip4n(self):
- """IPv4 address of remote peer - raw, suitable as API parameter"""
+ """IPv4 address of remote peer - raw, suitable as API parameter."""
return socket.inet_pton(socket.AF_INET, self.remote_ip4)
@property
def local_ip6(self):
- """Local IPv6 address on VPP interface (string)"""
+ """Local IPv6 address on VPP interface (string)."""
return self._local_ip6
@property
def local_ip6n(self):
- """Local IPv6 address - raw, suitable as API parameter"""
+ """Local IPv6 address - raw, suitable as API parameter."""
return socket.inet_pton(socket.AF_INET6, self.local_ip6)
@property
def remote_ip6(self):
- """IPv6 address of remote peer "connected" to this interface"""
+ """IPv6 address of remote peer "connected" to this interface."""
return self._remote_hosts[0].ip6
@property
@@ -68,17 +66,17 @@ class VppInterface(object):
@property
def name(self):
- """Name of the interface"""
+ """Name of the interface."""
return self._name
@property
def dump(self):
- """Raw result of sw_interface_dump for this interface"""
+ """RAW result of sw_interface_dump for this interface."""
return self._dump
@property
def test(self):
- """Test case creating this interface"""
+ """Test case creating this interface."""
return self._test
@property
@@ -88,20 +86,44 @@ class VppInterface(object):
@remote_hosts.setter
def remote_hosts(self, value):
+ """
+ :param list value: List of remote hosts.
+ """
self._remote_hosts = value
- #TODO: set hosts_by dicts
+ self._hosts_by_mac = {}
+ self._hosts_by_ip4 = {}
+ self._hosts_by_ip6 = {}
+ for host in self._remote_hosts:
+ self._hosts_by_mac[host.mac] = host
+ self._hosts_by_ip4[host.ip4] = host
+ self._hosts_by_ip6[host.ip6] = host
def host_by_mac(self, mac):
+ """
+ :param ip: MAC address to find host by.
+ :return: Host object assigned to interface.
+ """
return self._hosts_by_mac[mac]
def host_by_ip4(self, ip):
+ """
+ :param ip: IPv4 address to find host by.
+ :return: Host object assigned to interface.
+ """
return self._hosts_by_ip4[ip]
def host_by_ip6(self, ip):
+ """
+ :param ip: IPv6 address to find host by.
+ :return: Host object assigned to interface.
+ """
return self._hosts_by_ip6[ip]
def generate_remote_hosts(self, count=1):
- """Generate and add remote hosts for the interface."""
+ """Generate and add remote hosts for the interface.
+
+ :param int count: Number of generated remote hosts.
+ """
self._remote_hosts = []
self._hosts_by_mac = {}
self._hosts_by_ip4 = {}
@@ -117,7 +139,7 @@ class VppInterface(object):
self._hosts_by_ip6[ip6] = host
def post_init_setup(self):
- """Additional setup run after creating an interface object"""
+ """Additional setup run after creating an interface object."""
self.generate_remote_hosts()
@@ -149,21 +171,21 @@ class VppInterface(object):
(self.__name__, self.remote_mac, self.remote_ip4, self.local_ip4))
def config_ip4(self):
- """Configure IPv4 address on the VPP interface"""
+ """Configure IPv4 address on the VPP interface."""
addr = self.local_ip4n
addr_len = 24
self.test.vapi.sw_interface_add_del_address(
self.sw_if_index, addr, addr_len)
- def configure_extend_ipv4_mac_binding(self):
- """Configure neighbor MAC to IPv4 addresses."""
+ def configure_ipv4_neighbors(self):
+ """For every remote host assign neighbor's MAC to IPv4 addresses."""
for host in self._remote_hosts:
macn = host.mac.replace(":", "").decode('hex')
ipn = host.ip4n
self.test.vapi.ip_neighbor_add_del(self.sw_if_index, macn, ipn)
def config_ip6(self):
- """Configure IPv6 address on the VPP interface"""
+ """Configure IPv6 address on the VPP interface."""
addr = self._local_ip6n
addr_len = 64
self.test.vapi.sw_interface_add_del_address(
@@ -171,30 +193,31 @@ class VppInterface(object):
def set_table_ip4(self, table_id):
"""Set the interface in a IPv4 Table.
- Must be called before configuring IP4 addresses"""
+
+ .. note:: Must be called before configuring IP4 addresses."""
self.test.vapi.sw_interface_set_table(
self.sw_if_index, 0, table_id)
def set_table_ip6(self, table_id):
"""Set the interface in a IPv6 Table.
- Must be called before configuring IP6 addresses"""
+
+ .. note:: Must be called before configuring IP6 addresses.
+ """
self.test.vapi.sw_interface_set_table(
self.sw_if_index, 1, table_id)
def disable_ipv6_ra(self):
- """Configure IPv6 RA suppress on the VPP interface"""
+ """Configure IPv6 RA suppress on the VPP interface."""
self.test.vapi.sw_interface_ra_suppress(self.sw_if_index)
def admin_up(self):
- """ Put interface ADMIN-UP """
+ """Put interface ADMIN-UP."""
self.test.vapi.sw_interface_set_flags(self.sw_if_index, admin_up_down=1)
def add_sub_if(self, sub_if):
- """
- Register a sub-interface with this interface
+ """Register a sub-interface with this interface.
:param sub_if: sub-interface
-
"""
if not hasattr(self, 'sub_if'):
self.sub_if = sub_if
@@ -205,6 +228,6 @@ class VppInterface(object):
self.sub_if = sub_if
def enable_mpls(self):
- """Enable MPLS on the VPP interface"""
+ """Enable MPLS on the VPP interface."""
self.test.vapi.sw_interface_enable_disable_mpls(
self.sw_if_index)